@@ -7,9 +7,12 @@ import unittest
 from datetime import datetime, date, time, timedelta
 import math
 import struct
-from pyq import _k, Q_VERSION, _PY3K
+from pyq import _k, Q_VERSION, Q_OS
 
-if sys.maxsize == 2147483647:  # 32-bit platform
+_PY3K = 1
+
+WIN = Q_OS.startswith('w')
+if sys.maxsize == 2147483647 or WIN:  # 32-bit Unix or any Windows
     K_INT_CODE, K_LONG_CODE = "lq"
 else:
     K_INT_CODE, K_LONG_CODE = "il"
@@ -18,9 +21,9 @@ else:
 # extract _k.K class methods
 for m in ('func k knk ktd err dot a1'
           ' ka kb kg kh ki kj ke kf kc ks km kd kz ku kv kt kp'
-          ' ktn ktj kzz knz kpz b9 d9'
+          ' knt ktn ktj kzz knz kpz b9 d9'
           ' B G H I J E F S K P M D N U V T xT xD').split():
-    globals()[m] = getattr(_k.K, '_' + m)
+    globals()[m] = getattr(_k.K, '_' + m, None)
 del m
 
 
@@ -140,7 +143,7 @@ class ListTestCase(K_TestCase):
 
     def test_S(self):
         self.assert_k_is(S([]), '`symbol$()')
-        self.assert_k_is(S(['aa', 'bb']), '`aa`bb')
+        self.assert_k_is(S(['aa', 'bb', u'uu', None]), '`aa`bb`uu`')
 
     def test_K(self):
         self.assert_k_is(K([]), '()')
@@ -492,7 +495,7 @@ else:
     class NumPyTestCase(unittest.TestCase):
         def test_scalar(self):
             x = ki(0)
-            self.assertEquals(array(x).shape, ())
+            self.assertEqual(array(x).shape, ())
 
 
 def eq(a, b):
@@ -1207,6 +1210,7 @@ def test_attr_n(x, n):
     assert n == x._n
 
 
+@pytest.mark.skipif("Q_VERSION >= 3.6")
 def test_date_range():
     min_date = date(1709, 1, 1)
     max_date = date(2290, 12, 31)
@@ -1238,6 +1242,7 @@ def test_issue_870():
     assert eq(P(datetimes), result)
 
 
+@pytest.mark.skipif("Q_VERSION >= 3.6")
 def test_month_range():
     dates = map(date,
                 [1708, 1709, 2290, 2291],
@@ -1257,6 +1262,13 @@ def test_timestamp_range():
     assert eq(P(datetimes), result)
 
 
+@pytest.mark.skipif("Q_VERSION < 3.6")
+def test_date_and_month_extremes():
+    dates = [date.min, date.max]
+    assert eq(M(dates), q('0001.01 9999.12m'))
+    assert eq(D(dates), q('0001.01.01 9999.12.31'))
+
+
 @pytest.mark.parametrize("t,f", [
     ("boolean", "?"),
     ("byte", "B"),
@@ -1295,7 +1307,7 @@ def test_n_attribute_error():
     ('1j', 't', -7),
     # pytest.mark.skipif("Q_VERSION < 3", ('1', 'a', 3)),
     # -- unpredictable values
-    pytest.mark.skipif("Q_VERSION < 3", ('1', 'm', 0)),
+    pytest.param('1', 'm', 0, marks=pytest.mark.skipif("Q_VERSION < 3")),
     ('"x"', 'c', b'x'),
     ('enlist 0x42', 'G', 0x42),
     ('enlist 42h', 'H', 42),
@@ -1349,15 +1361,15 @@ def test_call_kw_error():
 def test_data_attr_errors():
     # Empty list
     x = ktn(0, 0)
-    with pytest.raises(BufferError):
+    with pytest.raises(AttributeError):
         x.data
     # Scalar in generic list
     x = knk(2, ki(0), kj(0))
-    with pytest.raises(BufferError):
+    with pytest.raises(AttributeError):
         x.data
     # Size varies
     x = knk(2, I([]), I([0]))
-    with pytest.raises(BufferError):
+    with pytest.raises(AttributeError):
         x.data
 
 
@@ -1383,7 +1395,9 @@ def test_kb_error():
     ('ke', -1e200, 1e200, '0We'),
     ('kf', -float('inf'), float('inf'), '0w'),
     ('kd', -2 ** 31 - 1, 2 ** 31 + 1, '0Wd'),
-    ('kd', date.min, date.max, '0Wd'),
+    pytest.param('kd', date.min, date.max, '0Wd',
+                 marks=pytest.mark.skipif('Q_VERSION >= 3.6')),
+    ('km', -2 ** 31 - 1, 2 ** 31 + 1, '0Wm'),
     ('ku', -2 ** 31 - 1, 2 ** 31 + 1, '0Wu'),
     ('kv', -2 ** 31 - 1, 2 ** 31 + 1, '0Wv'),
     ('kpz', -2 ** 63 - 1, 2 ** 63 + 1, '0Wp'),
@@ -1452,3 +1466,22 @@ def test_inf_time_pys(x):
     x = q(x)
     with pytest.raises(OverflowError):
         x._pys()
+
+
+@pytest.mark.skipif("Q_VERSION < 3.5")
+def test_knt():
+    t = q('([]a:1 2;b:3 4)')
+    kt = q('([a:1 2];b:3 4)')
+    assert eq(knt(1, t), kt)
+    with pytest.raises(ValueError):
+        knt(0, t)
+    with pytest.raises(_k.error):
+        knt(2, t)
+
+
+def test_none_in_float_list():
+    a = [1., None]
+    b = F(a)
+    assert eq(b, q('1 0n'))
+    b = E(a)
+    assert eq(b, q('1 0ne'))
